==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes
 */
@JsonPropertyOrder({ SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes.JSON_PROPERTY_XSI_COLON_TYPE })
@JsonTypeName("SAMLPayLoad_data_assertion_claims_value_attributeValues_inner_attributes")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_XSI_COLON_TYPE = "xsi:type";
    private String xsiColonType;

    public SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes() {
    }

    public SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes xsiColonType(String xsiColonType) {

        this.xsiColonType = xsiColonType;
        return this;
    }

    /**
     * Used to derive the type of the attribute
     *
     * @return xsiColonType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Used to derive the type of the attribute")
    @JsonProperty(JSON_PROPERTY_XSI_COLON_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getXsiColonType() {
        return xsiColonType;
    }

    @JsonProperty(JSON_PROPERTY_XSI_COLON_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setXsiColonType(String xsiColonType) {
        this.xsiColonType = xsiColonType;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes saMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes = (SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes) o;
        return Objects.equals(this.xsiColonType,
                saMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes.xsiColonType);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(xsiColonType);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes {\n");
        sb.append("    xsiColonType: ").append(toIndentedString(xsiColonType)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes
 */
@JsonPropertyOrder({ SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes.JSON_PROPERTY_XSI_COLON_TYPE })
@JsonTypeName("SAMLPayLoad_data_assertion_claims_value_attributeValues_inner_attributes")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_XSI_COLON_TYPE = "xsi:type";
    private String xsiColonType;

    public SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes() {
    }

    public SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes xsiColonType(String xsiColonType) {

        this.xsiColonType = xsiColonType;
        return this;
    }

    /**
     * Used to derive the type of the attribute
     *
     * @return xsiColonType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Used to derive the type of the attribute")
    @JsonProperty(JSON_PROPERTY_XSI_COLON_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getXsiColonType() {
        return xsiColonType;
    }

    @JsonProperty(JSON_PROPERTY_XSI_COLON_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setXsiColonType(String xsiColonType) {
        this.xsiColonType = xsiColonType;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes saMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes = (SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes) o;
        return Objects.equals(this.xsiColonType,
                saMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes.xsiColonType);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(xsiColonType);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes {\n");
        sb.append("    xsiColonType: ").append(toIndentedString(xsiColonType)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
